@@ -1,5 +1,4 @@
-use core::ptr::{self};
-use core::slice::{self};
+use core::{ptr, slice};
 
 use super::{Drain, Vec};
 use crate::alloc::{Allocator, Global};
@@ -50,6 +49,7 @@ impl<I: Iterator, A: Allocator> DoubleEndedIterator for Splice<'_, I, A> {
 #[stable(feature = "vec_splice", since = "1.21.0")]
 impl<I: Iterator, A: Allocator> ExactSizeIterator for Splice<'_, I, A> {}
 
+// See also: [`crate::collections::vec_deque::Splice`].
 #[stable(feature = "vec_splice", since = "1.21.0")]
 impl<I: Iterator, A: Allocator> Drop for Splice<'_, I, A> {
     fn drop(&mut self) {
