@@ -3,6 +3,8 @@
 
 use crate::any::TypeId;
 use crate::intrinsics::{type_id, type_of};
+use crate::marker::PointeeSized;
+use crate::ptr::DynMetadata;
 
 /// Compile-time type information.
 #[derive(Debug)]
@@ -16,6 +18,21 @@ pub struct Type {
     pub size: Option<usize>,
 }
 
+/// Info of a trait implementation, you can retrieve the vtable with [Self::get_vtable]
+#[derive(Debug, PartialEq, Eq)]
+#[unstable(feature = "type_info", issue = "146922")]
+#[non_exhaustive]
+pub struct TraitImpl<T: PointeeSized> {
+    pub(crate) vtable: DynMetadata<T>,
+}
+
+impl<T: PointeeSized> TraitImpl<T> {
+    /// Gets the raw vtable for type reflection mapping
+    pub const fn get_vtable(&self) -> DynMetadata<T> {
+        self.vtable
+    }
+}
+
 impl TypeId {
     /// Compute the type information of a concrete type.
     /// It can only be called at compile time.
@@ -75,6 +92,8 @@ pub enum TypeKind {
     Reference(Reference),
     /// Pointers.
     Pointer(Pointer),
+    /// Function pointers.
+    FnPtr(FnPtr),
     /// FIXME(#146922): add all the common types
     Other,
 }
@@ -151,7 +170,7 @@ pub struct Trait {
     pub is_auto: bool,
 }
 
-/// Compile-time type information about arrays.
+/// Compile-time type information about structs.
 #[derive(Debug)]
 #[non_exhaustive]
 #[unstable(feature = "type_info", issue = "146922")]
@@ -305,3 +324,39 @@ pub struct Pointer {
     /// Whether this pointer is mutable or not.
     pub mutable: bool,
 }
+
+#[derive(Debug)]
+#[unstable(feature = "type_info", issue = "146922")]
+/// Function pointer, e.g. fn(u8),
+pub struct FnPtr {
+    /// Unsafety, true is unsafe
+    pub unsafety: bool,
+
+    /// Abi, e.g. extern "C"
+    pub abi: Abi,
+
+    /// Function inputs
+    pub inputs: &'static [TypeId],
+
+    /// Function return type, default is TypeId::of::<()>
+    pub output: TypeId,
+
+    /// Vardiadic function, e.g. extern "C" fn add(n: usize, mut args: ...);
+    pub variadic: bool,
+}
+
+#[derive(Debug, Default)]
+#[non_exhaustive]
+#[unstable(feature = "type_info", issue = "146922")]
+/// Abi of [FnPtr]
+pub enum Abi {
+    /// Named abi, e.g. extern "custom", "stdcall" etc.
+    Named(&'static str),
+
+    /// Default
+    #[default]
+    ExternRust,
+
+    /// C-calling convention
+    ExternC,
+}
