@@ -59,12 +59,31 @@ pub use crate::hash::macros::Hash;
 
 #[stable(feature = "builtin_macro_prelude", since = "1.38.0")]
 #[doc(no_inline)]
+#[expect(deprecated)]
 pub use crate::{
-    assert, cfg, column, compile_error, concat, env, file, format_args,
-    format_args_nl, include, include_bytes, include_str, line, log_syntax, module_path, option_env,
-    stringify, trace_macros,
+    assert, assert_eq, assert_ne, cfg, column, compile_error, concat, debug_assert, debug_assert_eq,
+    debug_assert_ne, file, format_args, include, include_bytes, include_str, line, matches,
+    module_path, option_env, stringify, todo, r#try, unimplemented, unreachable, write, writeln,
 };
 
+// These macros need special handling, so that we don't export them *and* the modules of the same
+// name. We only want the macros in the prelude so we shadow the original modules with private
+// modules with the same names.
+mod ambiguous_macros_only {
+    mod env {}
+    #[expect(hidden_glob_reexports)]
+    mod panic {}
+    #[stable(feature = "builtin_macro_prelude", since = "1.38.0")]
+    pub use crate::*;
+}
+#[stable(feature = "builtin_macro_prelude", since = "1.38.0")]
+#[doc(no_inline)]
+pub use self::ambiguous_macros_only::{env, panic};
+
+#[stable(feature = "cfg_select", since = "CURRENT_RUSTC_VERSION")]
+#[doc(no_inline)]
+pub use crate::cfg_select;
+
 #[unstable(
     feature = "concat_bytes",
     issue = "87555",
@@ -73,6 +92,30 @@ pub use crate::{
 #[doc(no_inline)]
 pub use crate::concat_bytes;
 
+#[unstable(feature = "const_format_args", issue = "none")]
+#[doc(no_inline)]
+pub use crate::const_format_args;
+
+#[unstable(
+    feature = "log_syntax",
+    issue = "29598",
+    reason = "`log_syntax!` is not stable enough for use and is subject to change"
+)]
+#[doc(no_inline)]
+pub use crate::log_syntax;
+
+#[unstable(feature = "pattern_type_macro", issue = "123646")]
+#[doc(no_inline)]
+pub use crate::pattern_type;
+
+#[unstable(
+    feature = "trace_macros",
+    issue = "29598",
+    reason = "`trace_macros` is not stable enough for use and is subject to change"
+)]
+#[doc(no_inline)]
+pub use crate::trace_macros;
+
 // Do not `doc(no_inline)` so that they become doc items on their own
 // (no public module for them to be re-exported from).
 #[stable(feature = "builtin_macro_prelude", since = "1.38.0")]
@@ -122,4 +165,4 @@ pub use crate::macros::builtin::define_opaque;
 pub use crate::macros::builtin::{eii, unsafe_eii};
 
 #[unstable(feature = "eii_internals", issue = "none")]
-pub use crate::macros::builtin::eii_extern_target;
+pub use crate::macros::builtin::eii_declaration;
