@@ -1,3 +1,7 @@
+mod fn_ptr;
+mod trait_info_of;
+mod type_info;
+
 use core::mem::*;
 use core::{array, ptr};
 use std::cell::Cell;
