@@ -57,10 +57,6 @@ pub fn home_dir() -> Option<PathBuf> {
     None
 }
 
-pub fn exit(code: i32) -> ! {
-    unsafe { hermit_abi::exit(code) }
-}
-
 pub fn getpid() -> u32 {
     unsafe { hermit_abi::getpid() as u32 }
 }
